# Code 4.3  Lorenz correlation dimension (lorenz_D2.R)
#
parms<- c(10,8/3,28)  # parameters: sigma, beta, rho
tinit<- 0
tfin<- 100
step<- 0.01
times<-seq(tinit,tfin,by=step)
funct<- function(t,integ,parms){             # the system of equations
  x<-integ[1]
  y<-integ[2]
  z<-integ[3]
  sigma<- parms[1]
  beta<-  parms[2]
  rho<-   parms[3]
  dx<- sigma*(y-x)           # that is  dx/dt = sigma\(y-x)
  dy<- x*(rho-z)-y           # that is  dy/dt = x(rho-z)-y
  dz<- x*y-beta*z            # that is  dz/dt = xy -beta z
  list(c(dx,dy,dz))
}                  # end of funct
require(deSolve)
cinit<-c(1,1,1)
xyz<-lsoda(cinit,times,funct,parms)
trans<- 2000                      # integral time step considered as transient
x <- window(xyz[,2],trans)        # discard  initial transient
t_start<- trans*step - step       # new initial time
t_time<-seq(t_start,tfin,by=step) # new time interval
require(tseriesChaos)
m<- 3                              # embedding dimension
d<- 10                             # time delay
xyz <- embedd(x,m,d)               # embed the 'observed' series
#library(scatterplot3d)            # here it is useless
#scatterplot3d(xyz, type="l")
################# up to here it is as in lorenz_attractor.R with the embedding

# estimate of D2
C.m <- d2(x,m=6,d=10,t=100,eps.min=0.01,neps=100)  # correlation integral, m = 1,...,6
C.m <- data.frame(unclass(C.m))                    # class attribute removed
C.3 <- subset(C.m,eps > 0.1 & eps < 1.2, select=c(eps,m3))         # eps in [0.1, 1.2]
lm(log(m3)~log(eps), data = C.3)        # D2 estimate with m=3
# windows()                             # do not comment if other plots are made before
par(mai=c(1.02,1.,0.82,0.42)+0.2)	    # to control the margin size
plot(C.m[,1],C.m[,4], type="l",log="xy",main="",
     xlab=expression(paste(epsilon)),ylab=expression(paste(widehat(C),(epsilon))),
     lwd=2,lty=1,cex.axis=1.3,cex.lab=2.0, xlim=c(0.01,100),ylim=c(0.00000002,1))
# stop here to plot only C(m=3)
##########################################
# add the lines below to plot C(m=1,...,6)
n.m<- ncol(C.m)
for(i in (n.m-0):2) lines(C.m[,c(1,i)],lwd=2)